# frozen_string_literal: true

#
# This Class is used to handle the logging for ManageIQ and an IDE
#
# Methods Summary:
#  > Name               > Description/Params
# initialize   - Create the connection to the client
#                 name      - String  : The name of the class/method/instantiator
#
# log          - Logs detail in the relevant manner
#                 level           - String   : info, warn, error
#                 message         - String   : The message
#                 logtoscreenonly - Boolean  : Log it to screen only
#                 notify          - Boolean  : process through the notify class
#
require_relative 'notification.rb'

# Wrapper class for logging
class LoggingClass
  # initialize class
  def initialize(name)
    @initializer = name
    @notification = NotificationClass.new
  end

  def log(level:, message:, logtoscreenonly: false, notify: false, email_to: nil, email_from: nil, signature: nil, webhookurl: nil, subjecttype: nil, update_message: false)
    levelvalid = %w[info warn error debug].any? { |msglevel| level.upcase.include? msglevel.to_s.upcase }

    if $evm.nil? || logtoscreenonly
      puts "#{level}: #{@initializer} - #{message}"
    elsif levelvalid
      $evm.log(level, "#{@initializer} - #{message}")
      @task.message = message if @task && (level.casecmp('ERROR').zero? || update_message)
    else
      $evm.log('info', "#{@initializer} - #{message}")
    end

    # Notify - Only if flag (notify) is set to TRUE
    @notification.notify(event_level: level, event_message: message, email_to: email_to, email_from: email_from, signature: signature, webhookurl: webhookurl, subjecttype: subjecttype) if notify
  rescue => err
    raise("Oopps! Something went wrong.\nDetails:<#{err}>")
  end
end
