# frozen_string_literal: true

# .SYNOPSIS
# This Class utilises the tiny_tds Ruby Gem (version => 2.1.0).
#
# Methods Summary:
#  > Name                   > Description/Params
# initialize       - Create the connection to the client
# get_client       - returns the client to utilise the tiny_tds functionality
# run_sql_query    - runs the specified sql query against the client when the class was instantiated
# close_connection - closes the connection to the client
#
require 'tiny_tds'
require_relative 'logging.rb'

# Wrapper class to interact with sql server
class SqlClass
  # Initialize Class
  def initialize(user:, password:, host:, database:, azure:, port: nil)
    # Logging
    @logger = LoggingClass.new(self.class.to_s)

    # Default port
    unless port.nil?
      @logger.log(level: 'info', message: 'Using default port 1433')
      port = '1433'
    end

    # Get connection to client
    client = TinyTds::Client.new(username: user,
                                 password: password,
                                 host: host,
                                 port: port,
                                 database: database,
                                 azure: azure)
    @client = client
  end

  # Return Client object
  def return_client
    @client
  end

  # Run Sql query
  def run_sql_query(sql)
    if @client.nil?
      @logger.log(level: 'warn', message: 'SQL Server Connection Not Established! Query hasn\'t been run!')
    else
      @logger.log(level: 'info', message: "Executing Sql Query: #{sql}")
      @client.execute(sql)
    end
  end

  # Close the connection to the sql client
  def close_connection
    @client.close unless @client.closed?
    @logger.log(level: 'info', message: 'Connection to SQL Client Closed Successfully.') if @client.closed?
  end
end
