# frozen_string_literal: true

#
# This Class is used to handle the running ssh scripts and utilises the net-ssh Ruby Gem (version => 4.2.0)
#
# Methods Summary:
#  > Name         > Description/Params
#    ssh_run      - Run script via ssh
#

require 'net/ssh'
require_relative 'logging.rb'

# This wrapper class is used to run ssh commands on linux machines
class SshClass
  def ssh_run(script, ipaddr, linux_user = nil, linux_password = nil)
    @logger = LoggingClass.new("#{self.class}:(#{__method__})")
    linux_user ||= 'root'
    linux_password ||= $evm.object.decrypt('linux_password').to_s
    begin
      Net::SSH.start(ipaddr, linux_user, password: linux_password, paranoid: Net::SSH::Verifiers::Null.new) do |ssh|
        command = script
        output = ssh.exec!(command)
        @logger.log(level: 'info', message: "ssh command being run on #{ipaddr}")
        @logger.log(level: 'info', message: "ssh script being run is #{script}")
        @logger.log(level: 'info', message: "SSH output = #{output}")
      end
    rescue => err
      raise("\n    Class:<#{self.class}>\n    Method:<#{__method__}>\n    Error:<#{err} - #{err.backtrace.join("\n")}>")
    end
  end
end
