# frozen_string_literal: true

#
# This Class is used to handle some of the heavily used VMWare utilities
#
# Methods Summary:
#  > Name                > Description/Params
# initialize             - Assign the host name
# get_vsphere_connection - returns the client connection
# retrieve_data_center   - returns the datacenter based on the connection and datacenter
# find_vm                - Get the VM details from vmware
# upg_tools              - Get the VM details from vmware
#
require 'rbvmomi'

# Wrapper class to interact with vmware
class VmwareClass
  def initialize(host_name)
    @host_name = host_name
  end

  def get_vsphere_connection(user, password)
    @connection = RbVmomi::VIM.connect(host: @host_name, user: user, password: password, insecure: true)
    @connection
  end

  def retrieve_data_center
    @connection.serviceInstance.find_datacenter || raise('Datacenter not found!') unless @connection.nil?
    raise("No connection established!\nUse the \"get_vsphere_connection\" method to connect.") if @connection.nil?
  end

  def find_vm(datacenter, vmname)
    vm = {}
    datacenter.datastoreFolder.childEntity.collect do |datastore|
      vm[:instance] = datastore.vm.find { |x| x.name == vmname }
      if vm[:instance]
        vm[:datastore] = datastore.name
        break
      end
    end
    vm
  end

  def upg_tools(vmobj)
    instopts = if vmobj[:instance][:guest][:guestFamily] == 'windowsGuest'
                 '/s /v "/qn REBOOT=ReallySuppress"'
               end
    vmobj[:instance].UpgradeTools_Task(installerOptions: instopts).wait_for_completion
  end
end
